pyhsm.basic_cmd.YHSM_Cmd_Key_Store_Decrypt

Package pyhsm :: Module basic_cmd :: Class YHSM_Cmd_Key_Store_Decrypt |
[frames] | no frames]

# Class YHSM_Cmd_Key_Store_Decrypt

    cmd.YHSM_Cmd --+
                   |
                  YHSM_Cmd_Key_Store_Decrypt

Have the YubiHSM decrypt it's key store using the master key.

If an incorrect master key is given, the key store will become unavailable (cleared from RAM in YubiHSM).

Instance Methods
__init__(self, stick, key=`'````'`) The base class for all YSM_ commands. |
bool |
parse_result(self, data) Parse result of pyhsm.defines.YSM_KEY_STORE_DECRYPT command. |
Inherited from `cmd.YHSM_Cmd`: `execute`

Class Variables
Inherited from `cmd.YHSM_Cmd`: `executed`, `response_status`

Instance Variables
integer | status = `None` The result of the unlock operation

Method Details

### __init__(self, stick, key=`'````'`) (Constructor) |
The base class for all YSM_ commands. Parameters: `stick` - Reference to a YubiHSM `command` - The YSM_xxx command defined in pyhsm.defines. `payload` - a packed C struct, represented as a Python string Overrides: cmd.YHSM_Cmd.__init__ (inherited documentation)

### parse_result(self, data) |
Parse result of pyhsm.defines.YSM_KEY_STORE_DECRYPT command. Returns: bool Only returns (True) on successful unlock Raises: `pyhsm.exception.YHSM_CommandFailed` - YubiHSM failed to unlock key store Overrides: cmd.YHSM_Cmd.parse_result